[![DOI](https://zenodo.org/badge/483941812.svg)](https://zenodo.org/doi/10.5281/zenodo.11146937)
[![test](https://github.com/fmi-faim/faim-ipa/actions/workflows/test.yml/badge.svg)](https://github.com/fmi-faim/faim-ipa/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/fmi-faim/faim-ipa/graph/badge.svg?token=YQ4W0A9RZL)](https://codecov.io/gh/fmi-faim/faim-ipa)
[![PyPI - Version](https://img.shields.io/pypi/v/faim-ipa.svg)](https://pypi.org/project/faim-ipa)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/faim-ipa/badges/version.svg)](https://anaconda.org/conda-forge/faim-ipa)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/faim-ipa.svg)](https://pypi.org/project/faim-ipa)

# FAIM-IPA
A collection of __I__mage __P__rocessing and __A__nalysis (IPA) functions we use at the Facility for Advanced Imaging and Microscopy (FAIM) at the Friedrich Miescher Institute for Biomedical Research (FMI).
